package de.uni_mannheim.informatik.dws.ontmatching.matchingevaltrackspecific.knowledgegraph;

import de.uni_mannheim.informatik.dws.ontmatching.matchingeval.ExecutionResult;
import de.uni_mannheim.informatik.dws.ontmatching.matchingeval.ExecutionResultSet;
import de.uni_mannheim.informatik.dws.ontmatching.matchingeval.Executor;
import de.uni_mannheim.informatik.dws.ontmatching.matchingeval.ExecutorSeals;
import de.uni_mannheim.informatik.dws.ontmatching.matchingeval.ResourceType;
import de.uni_mannheim.informatik.dws.ontmatching.matchingeval.evaluator.metric.cm.ConfusionMatrixMetric;
import de.uni_mannheim.informatik.dws.ontmatching.matchingeval.evaluator.visualization.DashboardBuilder;
import de.uni_mannheim.informatik.dws.ontmatching.matchingeval.refinement.Refiner;
import de.uni_mannheim.informatik.dws.ontmatching.matchingeval.refinement.TypeRefiner;
import de.uni_mannheim.informatik.dws.ontmatching.matchingeval.tracks.Track;
import de.uni_mannheim.informatik.dws.ontmatching.matchingeval.tracks.TrackRepository;
import de.uni_mannheim.informatik.dws.ontmatching.yetanotheralignmentapi.AlignmentXmlRepair;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.Writer;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.TimeUnit;
import org.apache.velocity.Template;
import org.apache.velocity.VelocityContext;
import org.apache.velocity.app.Velocity;
import org.apache.velocity.runtime.resource.loader.ClasspathResourceLoader;
import org.apache.velocity.tools.generic.NumberTool;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Evaluate the knwoledge graph track.
 */
public class EvalKnowledgeGraphTrack {
    private static final Logger LOGGER = LoggerFactory.getLogger(EvalKnowledgeGraphTrack.class);

    public static void main(String[] args){
        //runMatchers();
        //repairAlignmentFiles();
        generateResultsPage();
    }
    
    private static void runMatchers(){
        File sealsClientJar = new File("...");
        File sealsHome = new File("...");
        List<String> javaRuntimeParameters = Arrays.asList("-Xmx25g", "-Xms15g");
        
        //TestCase t = TrackRepository.Knowledgegraph.V3.getTestCase("marvelcinematicuniverse-marvel");
        Track t = TrackRepository.Knowledgegraph.V3;
        
        ExecutorSeals e = new ExecutorSeals(sealsClientJar, sealsHome, javaRuntimeParameters, 3, TimeUnit.HOURS);
        
        e.run(t, "/oaei/SEALS_MATCHER");
    }    
    
    private static void repairAlignmentFiles(){
        AlignmentXmlRepair.repairAlignmentFolder(new File("..."), new File("..."));
    }
    
    private static void generateResultsPage(){
        Velocity.setProperty("resource.loader", "classpath");
        Velocity.setProperty("classpath.resource.loader.class", ClasspathResourceLoader.class.getName());        
        Velocity.init();
        
        ExecutionResultSet results = Executor.loadFromFolder("...", TrackRepository.Knowledgegraph.V3);
        ConfusionMatrixMetric c = new ConfusionMatrixMetric(true, true);
        
        Template template = Velocity.getTemplate("KnowledgeGraphResultsPage_1.vm");
        VelocityContext context = new VelocityContext();
        context.put("util", new VelocityUtil(results, c));
        
        try(Writer writer = new FileWriter("KnowledgeGraphResultsPage.html")){
            template.merge( context, writer );
        } catch (IOException ex) {
            LOGGER.error("Could not write to file.", ex);
        }
        
        
        DashboardBuilder pb = new DashboardBuilder(results);
        pb.addDefaultDashboard();
        pb.writeToFile(new File("kgDashboard.html"), new File("kgDashboard_data.csv"));

    }
    
}
